==> apache-couchdb-2.3.1.tar.gz: apache-couchdb-2.3.1/src/fauxton/app/addons/components/react-components.js <==
// Licensed under the Apache License, Version 2.0 (the "License"); you may not
// use this file except in compliance with the License. You may obtain a copy of
// the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
// WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
// License for the specific language governing permissions and limitations under
// the License.

import {Badge, BadgeList} from './components/badge';
import {ToggleHeaderButton} from './components/toggleheaderbutton';
import {BulkActionComponent} from './components/bulkaction';
import {StyledSelect} from './components/styledselect';
import {StringEditModal} from './components/stringeditmodal';
import {CodeEditorPanel} from './components/codeeditorpanel';
import {CodeEditor} from './components/codeeditor';
import {ZenModeOverlay} from './components/zenmodeoverlay';
import {Beautify} from './components/beautify';
import {PaddedBorderedBox} from './components/paddedborderbox';
import {Document} from './components/document';
import {LoadLines} from './components/loadlines';
import {ConfirmButton} from './components/confirmbutton';
import {MenuDropDown} from './components/menudropdown';
import {TrayContents, TrayWrapper, connectToStores} from './components/tray';
import {ApiBarController} from './components/apibar';
import {DeleteDatabaseModal} from './components/deletedatabasemodal';
import {TabElement, TabElementWrapper} from './components/tabelement';
import {Polling, RefreshBtn} from './components/polling';
import {Copy} from './components/copy';
import {TabWindowWrapper} from './components/tabwindowwrapper';
import {ThrottledReactSelectAsync} from './components/throttledreacselect';

export default {
  BadgeList,
  Badge,
  BulkActionComponent,
  ConfirmButton,
  ToggleHeaderButton,
  StyledSelect,
  CodeEditorPanel,
  CodeEditor,
  StringEditModal,
  ZenModeOverlay,
  Beautify,
  PaddedBorderedBox,
  Polling,
  Document,
  LoadLines,
  MenuDropDown,
  TrayContents,
  TrayWrapper,
  connectToStores,
  ApiBarController,
  DeleteDatabaseModal,
  TabElement,
  TabElementWrapper,
  RefreshBtn,
  Copy,
  TabWindowWrapper,
  ThrottledReactSelectAsync
};

==> apache-couchdb-3.3.3.tar.gz: apache-couchdb-3.3.3/src/fauxton/app/addons/components/react-components.js <==
// Licensed under the Apache License, Version 2.0 (the "License"); you may not
// use this file except in compliance with the License. You may obtain a copy of
// the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
// WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
// License for the specific language governing permissions and limitations under
// the License.

import {Accordion, AccordionItem} from './components/accordion';
import {Badge, BadgeList} from './components/badge';
import {ToggleHeaderButton} from './components/toggleheaderbutton';
import {BulkActionComponent} from './components/bulkaction';
import {StyledSelect} from './components/styledselect';
import {StringEditModal} from './components/stringeditmodal';
import {CodeEditorPanel} from './components/codeeditorpanel';
import {CodeEditor} from './components/codeeditor';
import {ZenModeOverlay} from './components/zenmodeoverlay';
import {Beautify} from './components/beautify';
import {PaddedBorderedBox} from './components/paddedborderbox';
import {Document} from './components/document';
import {LoadLines} from './components/loadlines';
import {ConfirmButton} from './components/confirmbutton';
import {MenuDropDown} from './components/menudropdown';
import {TrayContents, TrayWrapper, connectToStores} from './components/tray';
import {DeleteDatabaseModal} from './components/deletedatabasemodal';
import {TabElement, TabElementWrapper} from './components/tabelement';
import {Polling, RefreshBtn} from './components/polling';
import {Copy} from './components/copy';
import {TabWindowWrapper} from './components/tabwindowwrapper';
import {ThrottledReactSelectAsync} from './components/throttledreacselect';

export default {
  Accordion,
  AccordionItem,
  BadgeList,
  Badge,
  BulkActionComponent,
  ConfirmButton,
  ToggleHeaderButton,
  StyledSelect,
  CodeEditorPanel,
  CodeEditor,
  StringEditModal,
  ZenModeOverlay,
  Beautify,
  PaddedBorderedBox,
  Polling,
  Document,
  LoadLines,
  MenuDropDown,
  TrayContents,
  TrayWrapper,
  connectToStores,
  DeleteDatabaseModal,
  TabElement,
  TabElementWrapper,
  RefreshBtn,
  Copy,
  TabWindowWrapper,
  ThrottledReactSelectAsync
};
